@@ -11,8 +11,8 @@ from rest_server.resource.models.helper import MyThread
 from test_framework.state import State
 from test_framework.state import TestType
 from test_framework.database.database import decorate_add_tests, decorate_update_test_state
-from test_framework.database.node_database import update_node_state, node_heart_beat
-from test_framework.state import NodeState
+from test_framework.database.dut_database import agent_heart_beat
+from test_framework.state import AgentState
 from test_framework.dut.dut import Dut
 from utils import log
 
@@ -34,10 +34,9 @@ class TestPool(object):
         self.thread_pool = list()
         self.test_pool = list()
         self._stop_flag = True
-        # self.run_manage_thread()
+        self.run_manage_thread()
         self.all_test_case = self.get_all_test_case()
         self.all_test_suite = self.get_all_test_suite()
-        self.refresh_dut()
 
     @staticmethod
     def refresh_dut():
@@ -119,11 +118,11 @@ class TestPool(object):
                 log.ERR(all_exception)
 
     def dut_state_manage(self):
-        _, node_state = self.init_node_state()
+        self.refresh_dut()
         while True:
             time.sleep(5)
             try:
-                _, node_state = self.check_and_update_node_state(node_state)
+                self.timing_refresh_dut()
                 self.heart_beat_check_env_state()
             except Exception as all_exception:
                 log.ERR(all_exception)
@@ -137,31 +136,19 @@ class TestPool(object):
                     self.test_pool[index]["state"] = State.NOT_START
                     break
 
-    @update_node_state
-    def init_node_state(self):
-        is_updated = True
-        node_state = NodeState.Online
-        return is_updated, node_state
-
-    @update_node_state
-    def check_and_update_node_state(self, org_node_state):
-        is_updated = False
-        latest_state = self.get_current_node_state()
-        if org_node_state != latest_state:
-            is_updated = True
+    def timing_refresh_dut(self):
         now = datetime.now(timezone(timedelta(hours=+8)))
         if (now.hour == 23 and now.minute == 59 and now.second in range(49, 59)) or\
                 (now.hour == 0 and now.minute == 0 and now.second in range(0, 10)):
-            is_updated = True
-        return is_updated, latest_state
+            self.refresh_dut()
 
-    def get_current_node_state(self):
+    def get_current_agent_state(self):
         tests = [test for test in self.test_pool if test["state"] in [State.NOT_START, State.RUNNING, State.NONE]]
         if tests:
-            node_state = NodeState.Running
+            agent_state = AgentState.Running
         else:
-            node_state = NodeState.Idle
-        return node_state
+            agent_state = AgentState.Online
+        return agent_state
 
     def _add_test_to_thread_pool(self, test):
         test_thread = {
@@ -178,7 +165,6 @@ class TestPool(object):
         self.thread_pool.append(test_thread)
 
     def _has_running_test(self):
-        # running_threads = list(filter(lambda X: X["state"] == State.RUNNING, self.test_pool))
         result = True if self.thread_pool else False
         return result
 
@@ -278,7 +264,6 @@ class TestPool(object):
     @decorate_add_tests
     def add_test(self, test_name, test_type, test_parameters=None):
         if self._check_test_is_exist(test_name, test_type):
-            self.set_target_ip_parameter(test_parameters)
             unique_code = self._get_unique_code()
             if test_parameters is not None:
                 test_parameters["key"] = unique_code
@@ -336,27 +321,10 @@ class TestPool(object):
             result = None
         return result, state
 
-    @node_heart_beat
+    @agent_heart_beat
     def heart_beat_check_env_state(self):
-        state = self.get_env_state()
-        return state
-
-    def get_env_state(self):
-        ret = self.get_current_node_state()
-        state = "running" if ret == NodeState.Running else "idle"
-        return state
-
-    @staticmethod
-    def set_target_ip_parameter(parameters):
-        """
-        this is for powercycle test case, need to set the target ip to env parameters
-        the when test run, can get the target ip, and update target env state in db
-        :param parameters:
-        :return:
-        """
-        if type(parameters) is dict:
-            if "TARGETIP" in parameters.keys():
-                os.environ["TARGETIP"] = parameters["TARGETIP"]
+        status = self.get_current_agent_state()
+        return status
 
     @staticmethod
     def set_test_parameters(parameters):
